==> nextcloud-27.1.5.tgz: nextcloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "See %s" : "Lihat %s",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silakan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "Other activities" : "Aktivitas lain",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "%sbit or higher PHP required." : "PHP %sbit atau yang lebih tinggi diperlukan.",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Server version %s or higher is required." : "Server versi %s atau yang lebih tinggi diperlukan.",
    "Server version %s or lower is required." : "Server versi %s atau yang lebih rendah diperlukan.",
    "Authentication" : "Otentikasi",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "Files" : "Berkas",
    "View profile" : "Tampilkan profil",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "File already exists" : "Berkas sudah ada",
    "Templates" : "Templat",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikasi \"%s\" tidak dapat dipasang karena berkas appinfo tidak dapat dibaca.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikasi \"%s\" tidak dapat dipasang karena tidak kompatibel dengan versi server ini",
    "__language_name__" : "Bahasa Indonesia",
    "Help" : "Bantuan",
    "Appearance and accessibility" : "Tampilan dan aksesibilitas",
    "Apps" : "Aplikasi",
    "Settings" : "Setelan",
    "Log out" : "Keluar",
    "Users" : "Pengguna",
    "Email" : "Surel",
    "Phone" : "Telpon",
    "Twitter" : "Twitter",
    "Website" : "Situs",
    "Address" : "Alamat",
    "Profile picture" : "Foto profil",
    "About" : "Tentang.",
    "Unknown user" : "Pengguna tidak dikenal",
    "Additional settings" : "Setelan tambahan",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan kata sandi admin.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Open »%s«" : "Buka »%s«",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Cannot increase permissions of %s" : "Tidak dapat menambah izin %s",
    "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "Sunday" : "Minggu",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sun." : "Min.",
    "Mon." : "Sen.",
    "Tue." : "Sel.",
    "Wed." : "Rab.",
    "Thu." : "Kam.",
    "Fri." : "Jum.",
    "Sat." : "Sab.",
    "Su" : "Min",
    "Mo" : "Sen",
    "Tu" : "Sel",
    "We" : "Rab",
    "Th" : "Kam",
    "Fr" : "Jum",
    "Sa" : "Sab",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maret",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Agustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mei",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Agu.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Tuliskan kata sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
    "User disabled" : "Pengguna dinonaktifkan",
    "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
    "a safe home for all your data" : "rumah yang aman untuk semua data Anda",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Application is not enabled" : "aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal module.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Menyesuaikan pengaturan ini di php.ini akan membuat Nextcloud berjalan kembali",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage unauthorized. %s" : "Penyimpanan tidak terotorisasi. %s",
    "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
    "Storage connection error. %s" : "Koneksi penyimpanan bermasalah. %s",
    "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
    "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
    "Full name" : "Nama lengkap",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Setidaknya libxml2 2.7.0 dibutuhkan. Saat ini %s dipasang.",
    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda."
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.6.tgz: nextcloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "See %s" : "Lihat %s",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silakan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "Other activities" : "Aktivitas lain",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "%sbit or higher PHP required." : "PHP %sbit atau yang lebih tinggi diperlukan.",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Server version %s or higher is required." : "Server versi %s atau yang lebih tinggi diperlukan.",
    "Server version %s or lower is required." : "Server versi %s atau yang lebih rendah diperlukan.",
    "Authentication" : "Otentikasi",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "Files" : "Berkas",
    "View profile" : "Tampilkan profil",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "File already exists" : "Berkas sudah ada",
    "Templates" : "Templat",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikasi \"%s\" tidak dapat dipasang karena berkas appinfo tidak dapat dibaca.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikasi \"%s\" tidak dapat dipasang karena tidak kompatibel dengan versi server ini",
    "__language_name__" : "Bahasa Indonesia",
    "Help" : "Bantuan",
    "Appearance and accessibility" : "Tampilan dan aksesibilitas",
    "Apps" : "Aplikasi",
    "Settings" : "Setelan",
    "Log out" : "Keluar",
    "Users" : "Pengguna",
    "Email" : "Surel",
    "Phone" : "Telpon",
    "Twitter" : "Twitter",
    "Website" : "Situs",
    "Address" : "Alamat",
    "Profile picture" : "Foto profil",
    "About" : "Tentang.",
    "Unknown user" : "Pengguna tidak dikenal",
    "Additional settings" : "Setelan tambahan",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan kata sandi admin.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Open »%s«" : "Buka »%s«",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Cannot increase permissions of %s" : "Tidak dapat menambah izin %s",
    "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "Sunday" : "Minggu",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sun." : "Min.",
    "Mon." : "Sen.",
    "Tue." : "Sel.",
    "Wed." : "Rab.",
    "Thu." : "Kam.",
    "Fri." : "Jum.",
    "Sat." : "Sab.",
    "Su" : "Min",
    "Mo" : "Sen",
    "Tu" : "Sel",
    "We" : "Rab",
    "Th" : "Kam",
    "Fr" : "Jum",
    "Sa" : "Sab",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maret",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Agustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mei",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Agu.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Tuliskan kata sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
    "User disabled" : "Pengguna dinonaktifkan",
    "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
    "a safe home for all your data" : "rumah yang aman untuk semua data Anda",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Application is not enabled" : "aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal modul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Menyesuaikan pengaturan ini di php.ini akan membuat Nextcloud berjalan kembali",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage unauthorized. %s" : "Penyimpanan tidak terotorisasi. %s",
    "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
    "Storage connection error. %s" : "Koneksi penyimpanan bermasalah. %s",
    "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
    "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
    "Full name" : "Nama lengkap",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Setidaknya libxml2 2.7.0 dibutuhkan. Saat ini %s dipasang.",
    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda."
},
"nplurals=1; plural=0;");
